# Author: Logan Tucker
# Date: 11.15.2021
# Purpose: Create a dictionary with location names as the keys and an objects holding relevant information as the values


from vertex import Vertex


# Purpose: Save relevant information from a line of text into separate variables
# Parameters: (line) a string read from a file
def parse_line1(line):
    # from each line, make a list splitting up relevant information
    attributes = line.split(";")

    # ID the location's name
    vertex_name = attributes[0].strip()

    # Submit a temporary empty list for adjlist to later be filled with Vertex objects of adjacent locations
    adjlist_vertices = []

    # ID the location's coordinates
    coordinates = attributes[2].strip().split(", ")

    return vertex_name, adjlist_vertices, coordinates


# Purpose: Save relevant information from a line of text into separate variables
# Parameters: (line) a string read from a file
def parse_line2(line):
    # from each line, make a list splitting up relevant information
    attributes = line.split(";")

    # ID the locations name
    vertex_name = attributes[0].strip()

    # save the names of each adjacent vertex into a list
    adjlist_names = attributes[1].strip().split(", ")

    return vertex_name, adjlist_names


# Purpose: Load information from a text file into a formatted dictionary
# Parameters: (filename) a string containing the name of the file storing the information needed for the dictionary
def load_graph(filename):

    vertex_dict = {}

    # read through 1: create Keys and object values (not including adjacent vertex information)
    file = open(filename, "r")

    for l in file:
        # if this is a line in the correct format:
        if len(l.split(";")) == 3:
            vertex_name, adjlist_vertices, coordinates = parse_line1(l)

        # create a graph vertex here and add it to the dictionary
            vertex_dict[vertex_name] = Vertex(vertex_name, adjlist_vertices, coordinates)

    file.close()

    # read through 2: input Vertex objects into the adjacent vertex lists (adjlist) held within the values of each key
    file = open(filename, "r")

    for l in file:
        # if this is a line in the correct format:
        if len(l.split(";")) == 3:
            vertex_name, adjlist_names = parse_line2(l)  # get name and adjacent names

            # add accurate references to vertex objects into adjlist of each location
            for adj in adjlist_names:
                vertex_dict[vertex_name].adjlist.append(vertex_dict[adj])

    file.close()

    return vertex_dict


load_graph("dartmouth_graph_extra_credit.txt")


