# Author: Logan Tucker
# Date: 11.16.2021
# Purpose: Animate navigation between two locations on Dartmouth's campus


from bfs import bfs
from cs1lib import *
from load_graph import *


# set variables
nav_active = False
start = None
goal = None

r = 0
g = 0
b = 1

curr_x = 0
curr_y = 0

clicked_x = 0
clicked_y = 0

vertex_dict = load_graph("dartmouth_graph_extra_credit.txt")


# set constants
MUTED = 0
HIGHLIGHTED = 1

HEIGHT = 811
WIDTH = 1012

IMG = load_image("dartmouth_map.png")

FONT = 25


# Purpose: Detect when and where the mouse is clicked
# Parameters: (mx, my) integers representing the current x and y coordinates of the mouse in the graphics window
def click(mx, my):
    global clicked_x, clicked_y

    clicked_x = mx
    clicked_y = my


# Purpose: Track the mouse's location
# Parameters: (mx, my) integers representing the current x and y coordinates of the mouse in the graphics window
def move(mx, my):
    global curr_x, curr_y

    curr_x = mx
    curr_y = my


# Purpose: Detect when the user selects a valid starting location for their navigation, (by clicking on it)
# Parameters: None
def select_start():
    global start, nav_active

    for vertex in vertex_dict:
        if vertex_dict[vertex].touch(clicked_x, clicked_y):  # if mouse clicked vertex
            vertex_dict[vertex].draw_vertex(HIGHLIGHTED, g, MUTED)

            start = vertex_dict[vertex]
            nav_active = True  # allow the navigation functions to execute

            label(start)  # # display the name of the start location

            return

    # if the user clicked a non valid location prevent the navigation functions from executing
    nav_active = False


# Purpose: Detect when the user selects a goal location, by hovering over it
# Parameters: None
def select_goal():
    global goal

    for vertex in vertex_dict:
        if vertex_dict[vertex].touch(curr_x, curr_y) and nav_active:  # if mouse hovering over vertex
            vertex_dict[vertex].draw_vertex(HIGHLIGHTED, g, MUTED)

            goal = vertex_dict[vertex]

    # display the name of the goal location
    if goal is not None and nav_active:
        label(goal)


# Purpose: Draw the name of a given location
# Parameters: (location) reference to a vertex object
def label(location):
    enable_stroke()
    set_font_size(FONT)
    set_font("Times")
    set_font_bold()
    set_stroke_color(MUTED, MUTED, MUTED)

    draw_text(str(location.name), int(location.coordinates[0]), int(location.coordinates[1]) - 20)
    disable_stroke()


# Purpose: Draw all vertices and edges
# Parameters: None
def draw_routes():
    for vertex in vertex_dict:
        vertex_dict[vertex].draw_vertex(r, g, b)  # circles
        vertex_dict[vertex].draw_adjacents(r, g, b)  # lines


# Purpose: Draw in a highlighted color the path between the start and the goal vertices
# Parameters: None
def nav():
    if nav_active:
        path = bfs(start, goal)

        for i in range(len(path) - 1):
            path[i].draw_vertex(HIGHLIGHTED, g, MUTED)
            path[i].draw_vertex_connection(path[i+1], HIGHLIGHTED, g, MUTED)


# Purpose: Animate navigation system
# Parameters: None
def main():
    draw_image(IMG, 0, 0)

    draw_routes()

    nav()

    select_start()
    select_goal()


start_graphics(main, mouse_move=move, mouse_press=click, width=WIDTH, height=HEIGHT)

