# Author: Logan Tucker
# Date: 11.17.2021
# Purpose: Create an class that stores information about a location on Dartmouth Campus


from cs1lib import *


# create constants
RADIUS = 10
WIDTH = 5


class Vertex:
    def __init__(self, name, adjlist, coordinates):
        self.name = name
        self.adjlist = adjlist  # list of references to objects of adjacent locations
        self.coordinates = coordinates

    # Purpose: Draw a single vertex's location as a circle on the map
    # Parameter: (r, g, b) integers to represent the color display of the circle
    def draw_vertex(self, r, g, b):
        disable_stroke()
        set_fill_color(r, g, b)

        # circle
        draw_circle(int(self.coordinates[0]), int(self.coordinates[1]), RADIUS)

    # Purpose: Draw a connection between a specified location(vertex) and the current location(vertex)
    # Parameter: (adj) a reference to another vertex, (r, g, b) integers to represent the color display of the circle
    def draw_vertex_connection(self, adj, r, g, b):
        set_fill_color(r, g, b)
        set_stroke_color(r, g, b)
        set_stroke_width(WIDTH)

        # circle
        disable_stroke()
        draw_circle(int(adj.coordinates[0]), int(adj.coordinates[1]), RADIUS)

        # line between current (self) and referenced vertices
        enable_stroke()
        draw_line(int(self.coordinates[0]), int(self.coordinates[1]), int(adj.coordinates[0]),
                  int(adj.coordinates[1]))

    # Purpose: Draw lines(edges) connecting vertex locations and their adjacent vertices
    # Parameters: (r, g, b) integers to represent the color display of the circle
    def draw_adjacents(self, r, g, b):
        enable_stroke()
        set_stroke_color(r, g, b)
        set_stroke_width(WIDTH)

        # draw edges
        for adj in self.adjlist:
            draw_line(int(self.coordinates[0]), int(self.coordinates[1]), int(adj.coordinates[0]),
                      int(adj.coordinates[1]))

    # Purpose: Detect weather a given x and y coordinate is "touching" / overlapping with the vertex's location
    # Parameter: (cx, cy) the current x and y locations of the mouse
    def touch(self, cx, cy):
        return (int(self.coordinates[0]) - RADIUS) < cx < (int(self.coordinates[0]) + RADIUS) and (int(self.coordinates[1]) - RADIUS) < cy < (int(self.coordinates[1]) + RADIUS)



